'use server';
import { NextResponse } from 'next/server';
import type { NextRequest } from 'next/server';
import { createUser } from '~/server/functions';
import { middleware } from '~/middleware';
import type { User } from '~/server/types';

export const POST = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const url = new URL(request.url);
    const appleId = url.searchParams.get('appleId');
    const email = url.searchParams.get('email');
    const fullName = url.searchParams.get('fullName');
    const pushToken = url.searchParams.get('pushToken');
    if (!appleId || !email || !fullName || !pushToken)
      return NextResponse.json(
        { message: 'Missing required parameters' }, { status: 400 }
      );
    const newUser: User | null = await createUser(appleId, email, fullName, pushToken);
    if (!newUser) {
      return NextResponse.json(
        { message: 'Error creating user' }, { status: 500 }
      );
    }
    return NextResponse.json(newUser);
  } catch (error) {
    console.error('Error creating user:', error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 500 });
    } else {
      return NextResponse.json({ message: 'Unknown error occurred' }, { status: 500 });
    }
  }
};
